Module: Google::Cloud::OrgPolicy

Defined in:
lib/google/cloud/org_policy.rb,
lib/google/cloud/org_policy/version.rb

Constant Summary collapse

VERSION =
"1.7.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.org_policy| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-org_policy library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



166
167
168
169
170
# File 'lib/google/cloud/org_policy.rb', line 166

def self.configure
  yield ::Google::Cloud.configure.org_policy if block_given?

  ::Google::Cloud.configure.org_policy
end

.org_policy(version: :v2, transport: :grpc, &block) ⇒ ::Object

Create a new client object for OrgPolicy.

By default, this returns an instance of Google::Cloud::OrgPolicy::V2::OrgPolicy::Client for a gRPC client for version V2 of the API. However, you can specify a different API version by passing it in the version parameter. If the OrgPolicy service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the OrgPolicy service. You can determine whether the method will succeed by calling org_policy_available?.

About OrgPolicy

An interface for managing organization policies.

The Organization Policy Service provides a simple mechanism for organizations to restrict the allowed configurations across their entire resource hierarchy.

You can use a policy to configure restrictions on resources. For example, you can enforce a policy that restricts which Google Cloud APIs can be activated in a certain part of your resource hierarchy, or prevents serial port access to VM instances in a particular folder.

Policies are inherited down through the resource hierarchy. A policy applied to a parent resource automatically applies to all its child resources unless overridden with a policy lower in the hierarchy.

A constraint defines an aspect of a resource's configuration that can be controlled by an organization's policy administrator. Policies are a collection of constraints that defines their allowable configuration on a particular resource and its child resources.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v2)

    The API version to connect to. Optional. Defaults to :v2.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



94
95
96
97
98
99
100
101
102
103
104
# File 'lib/google/cloud/org_policy.rb', line 94

def self.org_policy version: :v2, transport: :grpc, &block
  require "google/cloud/org_policy/#{version.to_s.downcase}"

  package_name = Google::Cloud::OrgPolicy
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::OrgPolicy.const_get(package_name).const_get(:OrgPolicy)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.org_policy_available?(version: :v2, transport: :grpc) ⇒ boolean

Determines whether the OrgPolicy service is supported by the current client. If true, you can retrieve a client object by calling org_policy. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the OrgPolicy service, or if the versioned client gem needs an update to support the OrgPolicy service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v2)

    The API version to connect to. Optional. Defaults to :v2.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/google/cloud/org_policy.rb', line 118

def self.org_policy_available? version: :v2, transport: :grpc
  require "google/cloud/org_policy/#{version.to_s.downcase}"
  package_name = Google::Cloud::OrgPolicy
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::OrgPolicy.const_get package_name
  return false unless service_module.const_defined? :OrgPolicy
  service_module = service_module.const_get :OrgPolicy
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end